Bookmarks

Bookmarks
=========

### Bookmarks bar {add_date="1447104782" last_modified="1476763970" personal_toolbar_folder="true"}

### NLP Book Manning {add_date="1476764546" last_modified="1476930924"}

### pycon2016-twip {add_date="1476930682" last_modified="1476930682"}

[Python Advanced: Finite State Machine in
Python](http://www.python-course.eu/finite_state_machine.php)

[Finite State Machine (FSM) « Python recipes « ActiveState
Code](http://code.activestate.com/recipes/146262-finite-state-machine-fsm/)

[www.cs.utsa.edu/\~bylander/cs2233/languageshandout.pdf](http://www.cs.utsa.edu/~bylander/cs2233/languageshandout.pdf)

[www.deepsky.com/\~merovech/voynich/voynich\_manchu\_reference\_materials/PDFs/jurafsky\_martin.pdf](http://www.deepsky.com/~merovech/voynich/voynich_manchu_reference_materials/PDFs/jurafsky_martin.pdf)

<https://www.cs.colorado.edu/~martin/SLP/Updates/1.pdf>

[stp.lingfil.uu.se/\~santinim/ml/2014/JurafskyMartinSpeechAndLanguageProcessing2ed\_draft
2007.pdf](http://stp.lingfil.uu.se/~santinim/ml/2014/JurafskyMartinSpeechAndLanguageProcessing2ed_draft%202007.pdf)

[www.librarian.net/wp-content/uploads/science-googlelabs.pdf](http://www.librarian.net/wp-content/uploads/science-googlelabs.pdf)

[PLAGIARISM\_DETECTION\_ALGORITHM\_USING\_NAT.pdf](file:///home/hobs/Downloads/PLAGIARISM_DETECTION_ALGORITHM_USING_NAT.pdf)

[gunthercox/ChatterBot](https://github.com/gunthercox/ChatterBot)

[An introduction to text analysis with Python, Part 1 | Neal
Caren](http://nealcaren.web.unc.edu/an-introduction-to-text-analysis-with-python-part-1/)

[Authorship Attribution and Forensic Linguistics with
Python/Scikit-Le…](http://www.slideshare.net/PyData/authorship-attribution-forensic-linguistics-with-python-scikit-learn-pandas-kostas-perifanos)

[ATG01](http://www.fb10.uni-bremen.de/anglistik/langpro/webspace/jb/info-pages/nlg/ATG01/ATG01.html)

[ACL Anthology » SIGGEN](http://www.aclweb.org/anthology/siggen.html)

[Timeline of NLG systems since 2000 - NLG Systems
Wiki](http://www.nlg-wiki.org/systems/Timeline_of_NLG_systems_since_2000)

[Implementing an online help desk system based on conversational
agent](http://dl.acm.org/citation.cfm?id=1643823.1643908)

[www.pnas.org/content/92/22/9977.full.pdf](http://www.pnas.org/content/92/22/9977.full.pdf)

[www.csie.ntu.edu.tw/\~lyuu/complexity/2012/20120918.pdf](http://www.csie.ntu.edu.tw/~lyuu/complexity/2012/20120918.pdf)

[Frontiers | Peer Reviewed Articles - Open Access
Journals](http://www.frontiersin.org/)

[Twitter Libraries | Twitter
Developers](https://dev.twitter.com/overview/api/twitter-libraries#python)

[Duke University sklearn TFIDF vectorizer
example](http://www.cs.duke.edu/courses/spring14/compsci290/assignments/lab02.html)

[www.cs.toronto.edu/\~ranzato/publications/ranzato-phd-thesis.pdf](http://www.cs.toronto.edu/~ranzato/publications/ranzato-phd-thesis.pdf)

[A Word is Worth a Thousand Vectors | Stitch Fix Technology –
Multithreaded](http://multithreaded.stitchfix.com/blog/2015/03/11/word-is-worth-a-thousand-vectors/)

[giladlotan/pydatanyc12\_gephi\_networkx: A lecture I gave at PyData NYC
2012 on using the networkx python library and Gephi to generate a
mapping of the python community on
Twitter](https://github.com/giladlotan/pydatanyc12_gephi_networkx)

[Implementing the Five Most Popular Similarity Measures in Python -
Dataconomy](http://dataconomy.com/implementing-the-five-most-popular-similarity-measures-in-python/)

[Presentation: Making an Impact with Python Natural Language Processing
Tools | PyCon 2016 in Portland,
OR](https://us.pycon.org/2016/schedule/presentation/1778/)

[localhost:8000/docs/slides/0 -
Introduction.html\#/making-an-impact-with-python-nlp](http://localhost:8000/docs/slides/0%20-%20Introduction.html#/making-an-impact-with-python-nlp)

<http://corenlp.run/>

[api.ai](https://console.api.ai/api-client/#/getStarted)

[chatbots.io](https://developer.pandorabots.com/)

### nlp-corpora-lexica {add_date="1476930606" last_modified="1476930606"}

[Word List Downloads](https://hashcat.net/forum/thread-1236.html)

[CrackStation's Password Cracking Dictionary (Pay what you
want!)](https://crackstation.net/buy-crackstation-wordlist-password-cracking-dictionary.htm)

[Google Ngram
Viewer](http://storage.googleapis.com/books/ngrams/books/datasetsv2.html)

### NLP {add_date="1476930589" last_modified="1476930589"}

[On a Connection between Kernel PCA and Metric Multidimensional
Scaling](http://papers.nips.cc/paper/1873-on-a-connection-between-kernel-pca-and-metric-multidimensional-scaling)

[Scale Space Segmentation and Latent Semantic Indexing for Hierarchical
Semantic
Indexing](https://engineering.purdue.edu/~malcolm/ibm/pubs/ICASSP2001-Segmentation.pdf)

[US Patent \# 7,137,062. System and method for hierarchical segmentation
with latent semantic indexing in scale space -
Patents.com](http://www.patents.com/us-7137062.html)

[PLOS ONE: A New Method Combining LDA and PLS for Dimension
Reduction](http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0096944)

[doctest](https://docs.djangoproject.com/en/1.8/topics/testing/overview/)

[web.media.mit.edu/\~javierhr/files/slidesPCA.pdf](http://web.media.mit.edu/~javierhr/files/slidesPCA.pdf)

[www2.ece.ohio-state.edu/\~aleix/pami01.pdf](http://www2.ece.ohio-state.edu/~aleix/pami01.pdf)

[A. Martinez, A. Kak PCA vs LDA - Google
Search](https://www.google.com/search?q=A.+Martinez%2C+A.+Kak+PCA+vs+LDA&oq=A.+Martinez%2C+A.+Kak++PCA+vs+LDA&aqs=chrome..69i57.6976j0j7&sourceid=chrome&es_sm=93&ie=UTF-8)

[www.cse.unr.edu/\~bebis/MathMethods/LDA/lecture.pdf](http://www.cse.unr.edu/~bebis/MathMethods/LDA/lecture.pdf)

### Context-Space NLP {add_date="1476930589" last_modified="1476930589"}

[Patent US7137062 - System and method for hierarchical segmentation with
latent semantic ... - Google
Patents](https://www.google.com/patents/US7137062)

### Skewed Skipgram Kernel {add_date="1476930589" last_modified="1476930589"}

[www.researchgate.net/profile/Sebastian\_Pado/publication/221013297\_A\_Structured\_Vector\_Space\_Model\_for\_Word\_Meaning\_in\_Context/links/0912f50bcab9830f66000000.pdf](http://www.researchgate.net/profile/Sebastian_Pado/publication/221013297_A_Structured_Vector_Space_Model_for_Word_Meaning_in_Context/links/0912f50bcab9830f66000000.pdf)

[delivery.acm.org/10.1145/1860000/1858012/p109-reisinger.pdf?ip=173.240.241.94&id=1858012&acc=OPEN&key=4D4702B0C3E38B35%2E4D4702B0C3E38B35%2E4D4702B0C3E38B35%2E6D218144511F3437&CFID=561435434&CFTOKEN=14949586&\_\_acm\_\_=1447954375\_0f0da7b0814c93ded7ca32da72cc](http://delivery.acm.org/10.1145/1860000/1858012/p109-reisinger.pdf?ip=173.240.241.94&id=1858012&acc=OPEN&key=4D4702B0C3E38B35%2E4D4702B0C3E38B35%2E4D4702B0C3E38B35%2E6D218144511F3437&CFID=561435434&CFTOKEN=14949586&__acm__=1447954375_0f0da7b0814c93ded7ca32da72cc2cd1)

[www.cs.fsu.edu/\~lifeifei/cis5930/lecture12-a.pdf](http://www.cs.fsu.edu/~lifeifei/cis5930/lecture12-a.pdf)

[gensim: models.word2vec – Deep learning with
word2vec](https://radimrehurek.com/gensim/models/word2vec.html)

[Word2vec Tutorial » RaRe
Technologies](http://rare-technologies.com/word2vec-tutorial/)

[word2vec - Tool for computing continuous distributed representations of
words. - Google Project Hosting](https://code.google.com/p/word2vec/)

[text-sentence 0.14 : Python Package
Index](https://pypi.python.org/pypi/text-sentence/)

[Recipes & FAQ · piskvorky/gensim
Wiki](https://github.com/piskvorky/gensim/wiki/Recipes-&-FAQ#q4-how-do-you-output-the-u-s-vt-matrices-of-lsi)

[gensim: models.lsimodel – Latent Semantic
Indexing](https://radimrehurek.com/gensim/models/lsimodel.html)

[www.ics.uci.edu/\~welling/classnotes/papers\_class/Fisher-LDA.pdf](http://www.ics.uci.edu/~welling/classnotes/papers_class/Fisher-LDA.pdf)

<https://www.cs.cmu.edu/~tom/10701_sp11/recitations/Recitation_11.pdf>

[Index of
/\~tom/10701\_sp11/recitations](https://www.cs.cmu.edu/~tom/10701_sp11/recitations/)

[Machine Learning 10-701/15-781 Spring
2011](https://www.cs.cmu.edu/~tom/10701_sp11/)

[Fuzzy String Matching in Python |
StreamHacker](http://streamhacker.com/2011/10/31/fuzzy-string-matching-python/)

### PyDX-hope {add_date="1476930481" last_modified="1476930481"}

[Apache Cordova](http://cordova.apache.org/)

[The Full List of Internet Top-Level and Country Code Domains (TLDs) |
gTLDs, ccTLDs and IDN](https://domainpunch.com/tlds/)

[\#Gamergate Trolls Aren't Ethics Crusaders; They're a Hate
Group](http://jezebel.com/gamergate-trolls-arent-ethics-crusaders-theyre-a-hate-1644984010)

[Saif: Lexicons](http://saifmohammad.com/WebPages/lexicons.html)

[vered1986/HypeNET: Integrated path-based and distributional method for
hypernymy detection](https://github.com/vered1986/HypeNet)

[collobert11a.dvi](http://ronan.collobert.com/pub/matos/2011_nlp_jmlr.pdf)

[Chatbot Fundamentals: An interactive guide to writing bots in
Python](https://apps.worldwritable.com/tutorials/chatbot/)

[ChatterBot 0.4.6 : Python Package
Index](https://pypi.python.org/pypi/ChatterBot)

[Wortschatz - International
Portal](http://corpora2.informatik.uni-leipzig.de/download.html)

[Downloads | Open American National
Corpus](http://www.anc.org/data/masc/downloads/)

[Santa Barbara Corpus of Spoken American English | Department of
Linguistics - UC Santa
Barbara](http://www.linguistics.ucsb.edu/research/santa-barbara-corpus)

[faculty.nps.edu/cmartell/NPSChat.htm](http://faculty.nps.edu/cmartell/NPSChat.htm)

[Introduction: Deep Learning for Chatbots | Open Data
Science](https://www.opendatascience.com/blog/introduction-deep-learning-for-chatbots-part-1/)

[Bullied 13-Year-Old Left Letter Before
Suicide](http://www.attn.com/stories/10746/bullied-13-year-old-writes-letter-before-suicide?utm_source=facebook&utm_medium=post&utm_campaign=internal)

[The Newer Hacker's
Dictionary](https://web.archive.org/web/20130827121341/http://cosman246.com/jargon.html)

[Cornell Movie-Dialogs
Corpus](http://www.cs.cornell.edu/~cristian/Cornell_Movie-Dialogs_Corpus.html)

[The musiXmatch Dataset | Million Song
Dataset](http://labrosa.ee.columbia.edu/millionsong/musixmatch#getting)

[Chatbots are a creation channel for storytelling | VentureBeat | Bots |
by Sar
Haribhakti](http://venturebeat.com/2016/09/02/chatbots-are-a-creation-channel-for-storytelling/)

[ShelfJoy – Dom's
Blog](https://domparkhurst.wordpress.com/tag/shelfjoy/)

[Facebook Chatbots Are Frustrating and
Useless](http://gizmodo.com/facebook-messenger-chatbots-are-more-frustrating-than-h-1770732045)

[Sequel Chatbot Platform for Messaging Apps Launches with Natural
Language and API Integration | Business
Wire](http://www.businesswire.com/news/home/20160602005463/en/Sequel-Chatbot-Platform-Messaging-Apps-Launches-Natural)

[language-bias.pdf](http://randomwalker.info/publications/language-bias.pdf)

[How bot-to-bot could soon replace APIs | VentureBeat | Bots | by Niko
Nelissen,
Etouches](http://venturebeat.com/2016/06/05/how-bot-to-bot-could-soon-replace-apis/)

[emoji by WOMANZINE by Forced Meme Productions -
issuu](https://issuu.com/lindseyweber5/docs/emoji_by_womanzine)

[How algorithms rule our working lives | Cathy O’Neil | Science | The
Guardian](https://www.theguardian.com/science/2016/sep/01/how-algorithms-rule-our-working-lives)

[totalgood/playground: Play with neural
networks!](https://github.com/totalgood/playground)

[IS2\_multidimensional-index-structures-in.pdf](http://infolab.usc.edu/csci599/Fall2002/paper/IS2_multidimensional-index-structures-in.pdf)

[paper\_grebhahn.pdf](http://ceur-ws.org/Vol-850/paper_grebhahn.pdf)

[Tf-idf :: A Single-Page Tutorial - Information Retrieval and Text
Mining](http://www.tfidf.com/)

[Deep Learning Cases: Text and Image
Processing](http://www.slideshare.net/grigorysapunov/deep-learning-cases-text-and-image-processing)

[Meet Viv: The Future Of Chatbots And Artificial Intelligence |
Lifehacker
Australia](http://www.lifehacker.com.au/2016/05/meet-viv-the-future-of-chatbots-and-artificial-intelligence/)

[Siri Inventor Dag Kittlaus hypes up “Viv”, the next big leap in AI |
BGR](http://bgr.com/2016/03/17/siri-inventor-dag-kittlaus-viv-global-brain/)

[nio.ieice.2014.pdf](http://isw3.naist.jp/~lasguido-l/me/__paper__/nio.ieice.2014.pdf)

[1603.06042v2.pdf](http://arxiv.org/pdf/1603.06042v2.pdf)

[tf-workshop.pdf](https://storage.googleapis.com/amy-jo/talks/tf-workshop.pdf)

[Research Blog: Chat Smarter with
Allo](https://research.googleblog.com/2016/05/chat-smarter-with-allo.html)

[Oriole Online
Tutorials](https://www.safaribooksonline.com/oriole/?utm_source=oreilly&utm_medium=newsite&utm_campaign=oriole-deep-learning)

[Conditional recurrent neural nets, generative AI Twitter bots, and
DL4J: Big data conference: Strata + Hadoop World, September 26 - 29,
2016, New York,
NY](http://conferences.oreilly.com/strata/hadoop-big-data-ny/public/schedule/detail/52036)

[\`\`](https://django-rest-swagger.readthedocs.io/en/latest/)

[PostgreSQL: Documentation: 9.1:
fuzzystrmatch](https://www.postgresql.org/docs/9.1/static/fuzzystrmatch.html)

[Daily UX conversations with your friendly UX Bear - UX
Chat](http://uxchat.me/)

[register [myPersonality
Project]](http://mypersonality.org/wiki/doku.php?id=register)

### forum moderation and chatbots {add_date="1476930481" last_modified="1476930481"}

[Troll Detection with Scikit-Learn | No Free
Hunch](http://blog.kaggle.com/2012/09/26/impermium-andreas-blog/)

[Chinese search giant Baidu has launched a medical
chatbot](http://www.businessinsider.com/chinese-search-giant-baidu-has-launched-a-medical-chatbot-2016-10?utm_source=feedburner&utm_medium=feed&utm_campaign=Feed%3A+typepad%2Falleyinsider%2Fsilicon_alley_insider+%28Silicon+Alley+Insider%29)

[Ozlo](https://www.ozlo.com/)

[UT College of Liberal
Arts:](https://liberalarts.utexas.edu/psychology/faculty/pennebak)

[The Science Behind
AnalyzeWords.com](http://analyzewords.com/science.php)

[abushawar05icamej.pdf](http://www.comp.leeds.ac.uk/eric/abushawar05icamej.pdf)

[ltc05\_faqchat.pdf](https://www.andy-roberts.net/res/writing/ltc05_faqchat.pdf)

[github/hubot: A customizable life embetterment
robot.](https://github.com/github/hubot)

[HUBOT](https://hubot.github.com/docs/)

[‘Chatbot’ pioneer builds free tool for law firms | News | Law Society
Gazette](http://www.lawgazette.co.uk/news/chatbot-pioneer-builds-free-tool-for-law-firms/5058339.fullarticle)

[​Obama's report on the future of artificial intelligence: The main
takeaways - Artificial
Intelligence](https://ai.icymi.email/obamas-report-on-the-future-of-artificialintelligence-the-main-takeaways-zdnet/)

[Box | Simple Online Collaboration: Online File Storage, FTP
Replacement, Team
Workspaces](https://manning.app.box.com/v/author-resources)

[49 Dictionary APIs |
ProgrammableWeb](http://www.programmableweb.com/category/dictionary/api)

[Pattern | CLiPS](http://www.clips.ua.ac.be/pages/pattern)

[Datasets | CLiPS](http://www.clips.ua.ac.be/datasets)

[TwiSty Corpus |
CLiPS](http://www.clips.ua.ac.be/datasets/twisty-corpus)

[Getting Started with Pattern – Text Mining
Online](http://textminingonline.com/getting-started-with-pattern)

[CS276: Information Retrieval and Web
Search](http://web.stanford.edu/class/cs276/)

[Contents](http://nlp.stanford.edu/IR-book/html/htmledition/contents-1.html)

[Linear Discriminant Analysis bit by
bit](http://sebastianraschka.com/Articles/2014_python_lda.html)

[Natural language processing in Python using NLTK. Part 1/3 -
YouTube](https://m.youtube.com/watch?feature=youtu.be&v=AOU-Yw1qdJs)

[jacobeisenstein/gt-nlp-class](https://github.com/jacobeisenstein/gt-nlp-class?files=1)

[github.com/Awesome-NLP](https://github.com/keonkim/awesome-nlp/blob/master/README.md#user-content-python)

### English Grammar

[Noun Phrase](http://www.chompchomp.com/terms/nounphrase.htm)


